import { ref, computed } from "vue";
import { defineStore } from "pinia";
export function JsonApiPiniaPlugin(context) {
  const { store, options } = context;
  const data = ref({});
  const meta = ref({});
  const links = ref({});
  const normalizeHandler = {
    get(target, prop, receiver) {
      if (["id", "type", "meta", "links"].includes(prop))
        return Reflect.get(target, prop, receiver);
      if (Object.keys(target.attributes || {}).includes(prop))
        return target.attributes?.[prop];
      if (Object.keys(target.relationships || {}).includes(prop)) {
        const relData = target.relationships?.[prop]?.data;
        if (!relData)
          return void 0;
        const storeInitMap = options.storeInitMap ?? {};
        if (Array.isArray(relData)) {
          return relData.map((data2) => {
            const storeInit2 = storeInitMap[data2.type] || {};
            const useRelStore2 = defineStore(data2.type, storeInit2);
            const relStore2 = useRelStore2();
            return relStore2.normalizedData[data2.id] || { id: data2.id, type: data2.type };
          });
        }
        const storeInit = storeInitMap[relData.type] || {};
        const useRelStore = defineStore(relData.type, storeInit);
        const relStore = useRelStore();
        return relStore.normalizedData[relData.id] || { id: relData.id, type: relData.type };
      }
      return void 0;
    },
    has() {
      return true;
    },
    ownKeys(target) {
      const targetAttributeKeys = Object.keys(target.attributes || {});
      const targetRelationshipKeys = Object.keys(target.relationships || {});
      return [
        "id",
        "type",
        "meta",
        "links",
        ...targetAttributeKeys,
        ...targetRelationshipKeys
      ];
    },
    getOwnPropertyDescriptor(target, prop) {
      return {
        value: normalizeHandler.get(target, prop),
        enumerable: true,
        configurable: true
      };
    }
  };
  const normalizedData = computed(
    () => Object.values(data.value).reduce(
      (acc, val) => ({
        ...acc,
        [val.id]: new Proxy(val, normalizeHandler)
      }),
      {}
    )
  );
  store.data = data;
  store.$state.data = data;
  store.normalizedData = normalizedData;
  store.$state.normalizedData = normalizedData;
  store.meta = meta;
  store.$state.meta = meta;
  store.links = links;
  store.$state.links = links;
  store.normalizedItem = (itemId) => normalizedData.value[itemId];
}
