import { getUrl } from "./utils.mjs";
let apiConf = {
  baseUrl: "http://localhost"
};
export const setApiConf = (conf) => {
  apiConf = conf;
};
export const indexRequest = async (resourceType, queryParams = {}, headers = new Headers()) => {
  const url = getUrl(apiConf.baseUrl || "", `/${resourceType}`);
  headers.append("Content-Type", "application/vnd.api+json");
  const conf = { method: "GET", headers };
  Object.keys(queryParams).forEach(
    (key) => url.searchParams.append(key, queryParams[key])
  );
  const response = await fetch(url.href, conf);
  if (!response.ok) {
    throw new Error(
      `Api call failed with status: ${response.status} and message: ${response.statusText}`
    );
  }
  return response.json();
};
export const getRequest = async (resourceType, id, queryParams = {}, headers = new Headers()) => {
  const url = getUrl(apiConf.baseUrl || "", `/${resourceType}/${id}`);
  headers.append("Content-Type", "application/vnd.api+json");
  const conf = { method: "GET", headers };
  Object.keys(queryParams).forEach(
    (key) => url.searchParams.append(key, queryParams[key])
  );
  const response = await fetch(url.href, conf);
  if (!response.ok) {
    throw new Error(
      `Api call failed with status: ${response.status} and message: ${response.statusText}`
    );
  }
  return response.json();
};
export const createRequest = async (resourceType, body, headers = new Headers()) => {
  const url = getUrl(apiConf.baseUrl || "", `/${resourceType}`);
  headers.append("Content-Type", "application/vnd.api+json");
  const conf = { method: "POST", headers, body: JSON.stringify(body) };
  const response = await fetch(url.href, conf);
  if (!response.ok) {
    throw new Error(
      `Api call failed with status: ${response.status} and message: ${response.statusText}`
    );
  }
  if (response.status === 204)
    return "";
  return response.json();
};
export const updateRequest = async (resourceType, id, body, headers = new Headers()) => {
  const url = getUrl(apiConf.baseUrl || "", `/${resourceType}/${id}`);
  headers.append("Content-Type", "application/vnd.api+json");
  const conf = { method: "PATCH", headers, body: JSON.stringify(body) };
  const response = await fetch(url.href, conf);
  if (!response.ok) {
    throw new Error(
      `Api call failed with status: ${response.status} and message: ${response.statusText}`
    );
  }
  if (response.status === 204)
    return "";
  return response.json();
};
export const deleteRequest = async (resourceType, id, headers = new Headers()) => {
  const url = getUrl(apiConf.baseUrl || "", `/${resourceType}/${id}`);
  headers.append("Content-Type", "application/vnd.api+json");
  const conf = { method: "DELETE", headers };
  const response = await fetch(url.href, conf);
  if (!response.ok) {
    throw new Error(
      `Api call failed with status: ${response.status} and message: ${response.statusText}`
    );
  }
  return response.json();
};
