"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.processUpdateData = exports.processIndexData = exports.processIncludedResources = exports.processGetData = exports.getUrl = void 0;
var _pinia = require("pinia");
var _lodashEs = require("lodash-es");
const customizer = (objValue, srcValue) => {
  if ((!objValue || (0, _lodashEs.isArray)(objValue)) && (0, _lodashEs.isArray)(srcValue)) {
    return srcValue;
  }
};
const getUrl = (baseUrl, url) => {
  if (url.startsWith("/")) {
    if (baseUrl.endsWith("/")) {
      return new URL(baseUrl.slice(0, -1) + url);
    }
    return new URL(baseUrl + url);
  }
  return new URL(url);
};
exports.getUrl = getUrl;
const processIncludedResources = (options, doc) => {
  if (doc?.included) {
    doc.included.forEach(includedResource => {
      const resourceType = includedResource.type;
      const useIncludedStore = (0, _pinia.defineStore)(resourceType, options.storeInitMap[resourceType] || {});
      const includedStore = useIncludedStore();
      if (options.merge) {
        if (!includedStore.data[includedResource.id]) {
          includedStore.data[includedResource.id] = {};
        }
        (0, _lodashEs.mergeWith)(includedStore.data[includedResource.id], includedResource, customizer);
      } else {
        includedStore.data[includedResource.id] = includedResource;
      }
    });
  }
};
exports.processIncludedResources = processIncludedResources;
const processIndexData = async (json, store, options) => {
  const jsonData = json.data;
  const insertData = jsonData.reduce((acc, val) => {
    return {
      ...acc,
      [val.id]: val
    };
  }, {});
  if (options.merge) {
    (0, _lodashEs.mergeWith)(store.data, insertData, customizer);
  } else {
    store.data = {
      ...store.data,
      ...insertData
    };
  }
  processIncludedResources(options, json);
  store.meta = json.meta;
  store.links = json.links;
};
exports.processIndexData = processIndexData;
const processGetData = async (json, store, options) => {
  const elementData = json.data;
  if (options.merge) {
    if (!store.data[elementData.id]) {
      store.data[elementData.id] = {};
    }
    (0, _lodashEs.mergeWith)(store.data[elementData.id], elementData, customizer);
  } else {
    store.data[elementData.id] = elementData;
  }
  processIncludedResources(options, json);
};
exports.processGetData = processGetData;
const processUpdateData = async (json, store, variables) => {
  if (typeof json === "string") {
    (0, _lodashEs.mergeWith)(store.data[variables.id], variables.body, customizer);
  } else {
    const elementData = json.data;
    store.data[variables.id] = elementData;
  }
};
exports.processUpdateData = processUpdateData;