import { defineStore } from "pinia";
import { mergeWith, isArray } from "lodash-es";
const customizer = (objValue, srcValue) => {
  if ((!objValue || isArray(objValue)) && isArray(srcValue)) {
    return srcValue;
  }
};
export const getUrl = (baseUrl, url) => {
  if (url.startsWith("/")) {
    if (baseUrl.endsWith("/")) {
      return new URL(baseUrl.slice(0, -1) + url);
    }
    return new URL(baseUrl + url);
  }
  return new URL(url);
};
export const processIncludedResources = (options, doc) => {
  if (doc?.included) {
    doc.included.forEach((includedResource) => {
      const resourceType = includedResource.type;
      const useIncludedStore = defineStore(
        resourceType,
        options.storeInitMap[resourceType] || {}
      );
      const includedStore = useIncludedStore();
      if (options.merge) {
        if (!includedStore.data[includedResource.id]) {
          includedStore.data[includedResource.id] = {};
        }
        mergeWith(
          includedStore.data[includedResource.id],
          includedResource,
          customizer
        );
      } else {
        includedStore.data[includedResource.id] = includedResource;
      }
    });
  }
};
export const processIndexData = async (json, store, options) => {
  const jsonData = json.data;
  const insertData = jsonData.reduce((acc, val) => {
    return { ...acc, [val.id]: val };
  }, {});
  if (options.merge) {
    mergeWith(store.data, insertData, customizer);
  } else {
    store.data = {
      ...store.data,
      ...insertData
    };
  }
  processIncludedResources(options, json);
  store.meta = json.meta;
  store.links = json.links;
};
export const processGetData = async (json, store, options) => {
  const elementData = json.data;
  if (options.merge) {
    if (!store.data[elementData.id]) {
      store.data[elementData.id] = {};
    }
    mergeWith(store.data[elementData.id], elementData, customizer);
  } else {
    store.data[elementData.id] = elementData;
  }
  processIncludedResources(options, json);
};
export const processUpdateData = async (json, store, variables) => {
  if (typeof json === "string") {
    mergeWith(store.data[variables.id], variables.body, customizer);
  } else {
    const elementData = json.data;
    store.data[variables.id] = elementData;
  }
};
