"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.storeVueQuery = exports.setStoreInitMap = void 0;
var _vue = require("vue");
var _vueQuery = require("@tanstack/vue-query");
var _requests = require("./requests.cjs");
var _utils = require("./utils.cjs");
let storeInitMap = {};
const setStoreInitMap = initMap => {
  storeInitMap = initMap;
};
exports.setStoreInitMap = setStoreInitMap;
const storeVueQuery = (store, apiResourceType, queryOptions) => {
  const resourceType = apiResourceType || store.$id;
  const indexKey = (0, _vue.reactive)([resourceType, {}]);
  const indexQuery = (0, _vueQuery.useQuery)(indexKey, () => (0, _requests.indexRequest)(resourceType, indexKey[1]), {
    keepPreviousData: true,
    staleTime: 1e4,
    ...queryOptions?.index
  });
  const index = async (queryParams = {}) => {
    indexKey[1] = queryParams;
  };
  (0, _vue.watch)(indexQuery.data, newData => {
    const data = newData;
    if (data) {
      const merge = queryOptions?.index?.merge ?? true;
      (0, _utils.processIndexData)(data, store, {
        storeInitMap,
        merge
      });
    }
  });
  const getKey = (0, _vue.reactive)([resourceType, "", {}]);
  const getQuery = (0, _vueQuery.useQuery)(getKey, () => (0, _requests.getRequest)(resourceType, getKey[1], getKey[2]), {
    staleTime: 1e4,
    ...queryOptions?.get
  });
  const get = async (id, queryParams = {}) => {
    getKey[1] = id;
    getKey[2] = queryParams;
  };
  (0, _vue.watch)(getQuery.data, newData => {
    const data = newData;
    if (data) {
      const merge = queryOptions?.index?.merge ?? true;
      (0, _utils.processGetData)(data, store, {
        storeInitMap,
        merge
      });
    }
  });
  const createQuery = (0, _vueQuery.useMutation)(params => (0, _requests.createRequest)(resourceType, params.body, params.headers), {
    onSuccess: (json, {
      body
    }) => {
      if (typeof json === "string") {
        store.data[body.id || ""] = body;
      } else {
        const elementData = json.data;
        store.data[elementData.id] = elementData;
      }
    },
    ...queryOptions?.create
  });
  const create = (body, headers = new Headers()) => {
    return createQuery.mutate({
      body,
      headers
    });
  };
  const updateQuery = (0, _vueQuery.useMutation)(params => (0, _requests.updateRequest)(resourceType, params.id, params.body, params.headers), {
    onSuccess: (json, {
      id,
      body
    }) => {
      (0, _utils.processUpdateData)(json, store, {
        id,
        body
      });
    },
    ...queryOptions?.update
  });
  const update = (id, body, headers = new Headers()) => {
    return updateQuery.mutate({
      id,
      body,
      headers
    });
  };
  const deleteQuery = (0, _vueQuery.useMutation)(params => (0, _requests.deleteRequest)(resourceType, params.id, params.headers), {
    onSuccess: (_, {
      id
    }) => {
      delete store.data[id];
    },
    ...queryOptions?.delete
  });
  const vDelete = async (id, headers = new Headers()) => {
    deleteQuery.mutate({
      id,
      headers
    });
  };
  return {
    index,
    indexQuery,
    get,
    getQuery,
    create,
    createQuery,
    update,
    updateQuery,
    delete: vDelete,
    deleteQuery
  };
};
exports.storeVueQuery = storeVueQuery;