import { reactive, watch } from "vue";
import { useQuery, useMutation } from "@tanstack/vue-query";
import { indexRequest, getRequest, createRequest, updateRequest, deleteRequest } from "./requests.mjs";
import { processIndexData, processGetData, processUpdateData } from "./utils.mjs";
let storeInitMap = {};
export const setStoreInitMap = (initMap) => {
  storeInitMap = initMap;
};
export const storeVueQuery = (store, apiResourceType, queryOptions) => {
  const resourceType = apiResourceType || store.$id;
  const indexKey = reactive([resourceType, {}]);
  const indexQuery = useQuery(
    indexKey,
    () => indexRequest(resourceType, indexKey[1]),
    {
      keepPreviousData: true,
      staleTime: 1e4,
      ...queryOptions?.index
    }
  );
  const index = async (queryParams = {}) => {
    indexKey[1] = queryParams;
  };
  watch(indexQuery.data, (newData) => {
    const data = newData;
    if (data) {
      const merge = queryOptions?.index?.merge ?? true;
      processIndexData(data, store, { storeInitMap, merge });
    }
  });
  const getKey = reactive([resourceType, "", {}]);
  const getQuery = useQuery(
    getKey,
    () => getRequest(resourceType, getKey[1], getKey[2]),
    {
      staleTime: 1e4,
      ...queryOptions?.get
    }
  );
  const get = async (id, queryParams = {}) => {
    getKey[1] = id;
    getKey[2] = queryParams;
  };
  watch(getQuery.data, (newData) => {
    const data = newData;
    if (data) {
      const merge = queryOptions?.index?.merge ?? true;
      processGetData(data, store, { storeInitMap, merge });
    }
  });
  const createQuery = useMutation(
    (params) => createRequest(resourceType, params.body, params.headers),
    {
      onSuccess: (json, { body }) => {
        if (typeof json === "string") {
          store.data[body.id || ""] = body;
        } else {
          const elementData = json.data;
          store.data[elementData.id] = elementData;
        }
      },
      ...queryOptions?.create
    }
  );
  const create = (body, headers = new Headers()) => {
    return createQuery.mutate({ body, headers });
  };
  const updateQuery = useMutation(
    (params) => updateRequest(resourceType, params.id, params.body, params.headers),
    {
      onSuccess: (json, { id, body }) => {
        processUpdateData(json, store, { id, body });
      },
      ...queryOptions?.update
    }
  );
  const update = (id, body, headers = new Headers()) => {
    return updateQuery.mutate({ id, body, headers });
  };
  const deleteQuery = useMutation(
    (params) => deleteRequest(resourceType, params.id, params.headers),
    {
      onSuccess: (_, { id }) => {
        delete store.data[id];
      },
      ...queryOptions?.delete
    }
  );
  const vDelete = async (id, headers = new Headers()) => {
    deleteQuery.mutate({ id, headers });
  };
  return {
    index,
    indexQuery,
    get,
    getQuery,
    create,
    createQuery,
    update,
    updateQuery,
    delete: vDelete,
    deleteQuery
  };
};
